pub struct XwaylandShellV1 { /* private fields */ }Expand description
context object for Xwayland shell
xwayland_shell_v1 is a singleton global object that provides the ability to create a xwayland_surface_v1 object for a given wl_surface.
This interface is intended to be bound by the Xwayland server.
A compositor must not allow clients other than Xwayland to bind to this interface. A compositor should hide this global from other clients’ wl_registry. A client the compositor does not consider to be an Xwayland server attempting to bind this interface will result in an implementation-defined error.
An Xwayland server that has bound this interface must not
set the WL_SURFACE_ID atom on a window.
This interface has no events.
Implementations
Sourceimpl XwaylandShellV1
impl XwaylandShellV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the Xwayland shell object
Destroy the xwayland_shell_v1 object.
The child objects created via this interface are unaffected.
Sourcepub fn get_xwayland_surface<U, D: 'static>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> XwaylandSurfaceV1
pub fn get_xwayland_surface<U, D: 'static>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> XwaylandSurfaceV1
assign the xwayland_surface surface role
Create an xwayland_surface_v1 interface for a given wl_surface object and gives it the xwayland_surface role.
It is illegal to create an xwayland_surface_v1 for a wl_surface
which already has an assigned role and this will result in the
role protocol error.
See the documentation of xwayland_surface_v1 for more details about what an xwayland_surface_v1 is and how it is used.